@@ -871,6 +871,7 @@ system.get_time = function()
     if primary_instance and ARGS[2] then
       local open_directory = false
       for i=2, #ARGS do
+        system.chdir(core.init_working_dir)
         local path = system.absolute_path(ARGS[i])
 
         if path then
@@ -919,7 +920,7 @@ end, {{name = "file", type = "string"}})
 ipc:register_method("core.open_directory", function(directory)
   if system.get_file_info(directory) then
     system.raise_window(core.window)
-    core.add_project_directory(directory)
+    core.add_project(directory)
   end
 end, {{name = "directory", type = "string"}})
 
