@@ -2,6 +2,7 @@
 
 int luaopen_system(lua_State *L);
 int luaopen_renderer(lua_State *L);
+int luaopen_renwindow(lua_State *L);
 int luaopen_regex(lua_State *L);
 int luaopen_process(lua_State *L);
 int luaopen_thread(lua_State* L);
@@ -26,6 +27,7 @@ int luaopen_encoding(lua_State* L);
 static const luaL_Reg libs[] = {
   { "system",     luaopen_system     },
   { "renderer",   luaopen_renderer   },
+  { "renwindow",  luaopen_renwindow  },
   { "regex",      luaopen_regex      },
   { "process",    luaopen_process    },
   { "thread",     luaopen_thread     },
