@@ -248,8 +248,9 @@ top:
         SDL_GetMouseState(&mx, &my);
         lua_pushstring(L, "filedropped");
         lua_pushstring(L, e.drop.file);
-        lua_pushinteger(L, mx);
-        lua_pushinteger(L, my);
+        // a DND into dock event fired before a window is created
+        lua_pushinteger(L, mx * (window_renderer ? window_renderer->scale_x : 0));
+        lua_pushinteger(L, my * (window_renderer ? window_renderer->scale_y : 0));
         SDL_free(e.drop.file);
         return 4;
       }
@@ -309,8 +310,8 @@ top:
         RenWindow* window_renderer = ren_find_window_from_id(e.button.windowID);
         lua_pushstring(L, "mousepressed");
         lua_pushstring(L, button_name(e.button.button));
-        lua_pushinteger(L, e.button.x);
-        lua_pushinteger(L, e.button.y);
+        lua_pushinteger(L, e.button.x * window_renderer->scale_x);
+        lua_pushinteger(L, e.button.y * window_renderer->scale_y);
         lua_pushinteger(L, e.button.clicks);
         return 5;
       }
@@ -321,8 +322,8 @@ top:
         RenWindow* window_renderer = ren_find_window_from_id(e.button.windowID);
         lua_pushstring(L, "mousereleased");
         lua_pushstring(L, button_name(e.button.button));
-        lua_pushinteger(L, e.button.x);
-        lua_pushinteger(L, e.button.y);
+        lua_pushinteger(L, e.button.x * window_renderer->scale_x);
+        lua_pushinteger(L, e.button.y * window_renderer->scale_y);
         return 4;
       }
 
@@ -337,10 +338,10 @@ top:
         }
         RenWindow* window_renderer = ren_find_window_from_id(e.motion.windowID);
         lua_pushstring(L, "mousemoved");
-        lua_pushinteger(L, e.motion.x);
-        lua_pushinteger(L, e.motion.y);
-        lua_pushinteger(L, e.motion.xrel);
-        lua_pushinteger(L, e.motion.yrel);
+        lua_pushinteger(L, e.motion.x * window_renderer->scale_x);
+        lua_pushinteger(L, e.motion.y * window_renderer->scale_y);
+        lua_pushinteger(L, e.motion.xrel * window_renderer->scale_x);
+        lua_pushinteger(L, e.motion.yrel * window_renderer->scale_y);
         return 5;
       }
 
@@ -562,6 +563,11 @@ static float x11_scale_factor() {
 #endif
 
 static int f_get_scale(lua_State *L) {
+#ifdef PRAGTICAL_USE_SDL_RENDERER
+  /* Since scaling is performed internally always return 1 */
+  lua_pushinteger(L, 1);
+  return 1;
+#else
   RenWindow *window_renderer = *(RenWindow**)luaL_checkudata(L, 1, API_TYPE_RENWINDOW);
   SDL_Window* window = window_renderer->window;
   static bool got_initial_scale = false;
@@ -577,7 +583,6 @@ static int f_get_scale(lua_State *L) {
   }
 
   float scale = 1.0;
-#ifndef __APPLE__
   char* env_scale = NULL;
   float system_scale = 0;
 #if _WIN32
@@ -614,10 +619,10 @@ static int f_get_scale(lua_State *L) {
   ) {
     scale = system_scale;
   }
-#endif /* __APPLE__ */
   got_initial_scale = true;
   lua_pushnumber(L, scale);
   return 1;
+#endif /* PRAGTICAL_USE_SDL_RENDERER */
 }
 
 static int f_set_window_title(lua_State *L) {
